"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveCSSByOffset = exports.resolveCSS = exports.getComplete = exports.resolveConfig = void 0;
const core_1 = require("@unocss/core");
const autocomplete_1 = require("@unocss/autocomplete");
const preset_uno_1 = __importDefault(require("@unocss/preset-uno"));
const config_1 = require("@unocss/config");
const presets_1 = require("unconfig/presets");
const defaultConfig = {
    presets: [(0, preset_uno_1.default)()],
    separators: []
};
const generator = (0, core_1.createGenerator)({}, defaultConfig);
let autocomplete = (0, autocomplete_1.createAutocomplete)(generator);
function resolveConfig(roorDir) {
    return (0, config_1.loadConfig)(process.cwd(), roorDir, [
        (0, presets_1.sourcePluginFactory)({
            files: ["vite.config", "svelte.config", "iles.config"],
            targetModule: "unocss/vite",
            parameters: [{ command: "serve", mode: "development" }],
        }),
        (0, presets_1.sourcePluginFactory)({
            files: ["astro.config"],
            targetModule: "unocss/astro",
        }),
        (0, presets_1.sourceObjectFields)({
            files: "nuxt.config",
            fields: "unocss",
        }),
    ]).then((result) => {
        generator.setConfig(result.config, defaultConfig);
        autocomplete = (0, autocomplete_1.createAutocomplete)(generator);
        return generator.config;
    });
}
exports.resolveConfig = resolveConfig;
function getComplete(content, cursor) {
    return autocomplete.suggestInFile(content, cursor);
}
exports.getComplete = getComplete;
function resolveCSS(item) {
    return generator.generate(item.label, {
        preflights: false,
        safelist: false,
    });
}
exports.resolveCSS = resolveCSS;
function resolveCSSByOffset(content, cursor) {
    return generator.generate((0, autocomplete_1.searchUsageBoundary)(content, cursor).content, {
        preflights: false,
        safelist: false,
    });
}
exports.resolveCSSByOffset = resolveCSSByOffset;
